Crate inpyt

Crate inpyt 

This is my first crate. Its task is to facilitate the programmer’s work by allowing the use of the well-known function “input()”.

This works the same way as in python, only you need to write ‘!’, since this is a macro: “input!()” or “input!(“Enter your name: “)”.

Macros

input
Outputs (or not) text and awaiting input. Outputs (or not) text and awaiting input.